.. _cloud_guides:

*******************
Public Cloud Guides
*******************

The guides in this section cover using Ansible with a range of public cloud platforms. They explore particular use cases in greater depth and provide a more "top-down" explanation of some basic features.

.. toctree::
   :maxdepth: 1

   guide_alicloud
   guide_aws
   guide_cloudstack
   guide_gce
   guide_azure
   guide_online
   guide_oracle
   guide_packet
   guide_rax
   guide_scaleway
   guide_vultr
